==> zego_uikit_prebuilt_live_streaming-3.1.7.tar.gz: lib/src/deprecated/deprecated_317.dart <==
// Project imports:
import 'package:zego_uikit_prebuilt_live_streaming/zego_uikit_prebuilt_live_streaming.dart';

const deprecatedTipsV317 = ', '
    'deprecated since 3.1.7, '
    'will be removed after 3.5.0'
    'Migrate Guide:https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration:%20v3.0-topic.html#317';

@Deprecated('Use ZegoLiveStreamingMenuBarButtonName instead$deprecatedTipsV317')
typedef ZegoMenuBarButtonName = ZegoLiveStreamingMenuBarButtonName;

@Deprecated('Use ZegoLiveStreamingDialogInfo instead$deprecatedTipsV317')
typedef ZegoDialogInfo = ZegoLiveStreamingDialogInfo;

@Deprecated(
    'Use ZegoLiveStreamingStartLiveButtonBuilder instead$deprecatedTipsV317')
typedef ZegoStartLiveButtonBuilder = ZegoLiveStreamingStartLiveButtonBuilder;

@Deprecated(
    'Use ZegoUIKitPrebuiltLiveStreamingInnerText instead$deprecatedTipsV317')
typedef ZegoInnerText = ZegoUIKitPrebuiltLiveStreamingInnerText;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestReceivedEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestReceivedEvent
    = ZegoLiveStreamingIncomingPKBattleRequestReceivedEvent;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestTimeoutEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestTimeoutEvent
    = ZegoLiveStreamingIncomingPKBattleRequestTimeoutEvent;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestCancelledEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestCancelledEvent
    = ZegoLiveStreamingIncomingPKBattleRequestCancelledEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestAcceptedEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestAcceptedEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestAcceptedEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestRejectedEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestRejectedEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestRejectedEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestTimeoutEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestTimeoutEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestTimeoutEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleEndedEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleEndedEvent = ZegoLiveStreamingPKBattleEndedEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleUserOfflineEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleUserOfflineEvent
    = ZegoLiveStreamingPKBattleUserOfflineEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleUserQuitEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleUserQuitEvent = ZegoLiveStreamingPKBattleUserQuitEvent;

==> zego_uikit_prebuilt_live_streaming-3.4.1.tar.gz: lib/src/deprecated/deprecated_317.dart <==
// Project imports:
import 'package:zego_uikit_prebuilt_live_streaming/zego_uikit_prebuilt_live_streaming.dart';

const deprecatedTipsV317 = ', '
    'deprecated since 3.1.7, '
    'will be removed after 3.5.0'
    'Migrate Guide:https://pub.dev/documentation/zego_uikit_prebuilt_live_streaming/latest/topics/Migration_v3.x-topic.html#317';

@Deprecated('Use ZegoLiveStreamingMenuBarButtonName instead$deprecatedTipsV317')
typedef ZegoMenuBarButtonName = ZegoLiveStreamingMenuBarButtonName;

@Deprecated('Use ZegoLiveStreamingDialogInfo instead$deprecatedTipsV317')
typedef ZegoDialogInfo = ZegoLiveStreamingDialogInfo;

@Deprecated(
    'Use ZegoLiveStreamingStartLiveButtonBuilder instead$deprecatedTipsV317')
typedef ZegoStartLiveButtonBuilder = ZegoLiveStreamingStartLiveButtonBuilder;

@Deprecated(
    'Use ZegoUIKitPrebuiltLiveStreamingInnerText instead$deprecatedTipsV317')
typedef ZegoInnerText = ZegoUIKitPrebuiltLiveStreamingInnerText;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestReceivedEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestReceivedEvent
    = ZegoLiveStreamingIncomingPKBattleRequestReceivedEvent;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestTimeoutEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestTimeoutEvent
    = ZegoLiveStreamingIncomingPKBattleRequestTimeoutEvent;

@Deprecated(
    'Use ZegoLiveStreamingIncomingPKBattleRequestCancelledEvent instead$deprecatedTipsV317')
typedef ZegoIncomingPKBattleRequestCancelledEvent
    = ZegoLiveStreamingIncomingPKBattleRequestCancelledEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestAcceptedEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestAcceptedEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestAcceptedEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestRejectedEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestRejectedEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestRejectedEvent;

@Deprecated(
    'Use ZegoLiveStreamingOutgoingPKBattleRequestTimeoutEvent instead$deprecatedTipsV317')
typedef ZegoOutgoingPKBattleRequestTimeoutEvent
    = ZegoLiveStreamingOutgoingPKBattleRequestTimeoutEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleEndedEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleEndedEvent = ZegoLiveStreamingPKBattleEndedEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleUserOfflineEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleUserOfflineEvent
    = ZegoLiveStreamingPKBattleUserOfflineEvent;

@Deprecated(
    'Use ZegoLiveStreamingPKBattleUserQuitEvent instead$deprecatedTipsV317')
typedef ZegoPKBattleUserQuitEvent = ZegoLiveStreamingPKBattleUserQuitEvent;
